pub enum OtlpProtocol {
Grpc,
HttpProtobuf,
HttpJson,
}Expand description
The protocol to use for OTLP exporter.
Variants
Implementations
Sourceimpl OtlpProtocol
impl OtlpProtocol
Sourcepub fn traces_protocol_from_env() -> Self
pub fn traces_protocol_from_env() -> Self
Returns the protocol to be used for exporting traces as defined by the environment.
Sourcepub fn metrics_protocol_from_env() -> Self
pub fn metrics_protocol_from_env() -> Self
Returns the protocol to be used for exporting metrics as defined by the environment.
Sourcepub fn logs_protocol_from_env() -> Self
pub fn logs_protocol_from_env() -> Self
Returns the protocol to be used for exporting logs as defined by the environment.