pub fn spin_disable_log_to_tracing() -> boolExpand description
Returns a boolean indicating if the compatibility layer that emits tracing events from applications logs should be disabled.
It is considered disabled if the environment variable SPIN_DISABLED_LOG_TO_TRACING is set and not
empty. By default the features is enabled.